@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2019, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -36,20 +36,13 @@ Documents by adding an empty plot with a title taken from ``args``.
 #-----------------------------------------------------------------------------
 # Boilerplate
 #-----------------------------------------------------------------------------
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-import logging
+import logging # isort:skip
 log = logging.getLogger(__name__)
 
 #-----------------------------------------------------------------------------
 # Imports
 #-----------------------------------------------------------------------------
 
-# Standard library imports
-
-# External imports
-import six
-
 # Bokeh imports
 from .code import CodeHandler
 
@@ -89,21 +82,10 @@ class ScriptHandler(CodeHandler):
             raise ValueError('Must pass a filename to ScriptHandler')
         filename = kwargs['filename']
 
-        # For Python 3, encoding must be set to utf-8 because:
-        # - when specifying an encoding in `io.open`, it doesn't
-        #   work with Python 2,
-        # - default encoding used by Python 3 `open` statement
-        #   is not 'utf-8' on Windows platform,
-        # - Python 3 `open` ignores le `coding` comment line.
-        # See https://github.com/bokeh/bokeh/pull/8202 for details.
-        if six.PY3:
-            with open(filename, 'r', encoding='utf-8') as f:
-                kwargs['source'] = f.read()
-        else:
-            with open(filename, 'r') as f:
-                kwargs['source'] = f.read()
+        with open(filename, 'r', encoding='utf-8') as f:
+            kwargs['source'] = f.read()
 
-        super(ScriptHandler, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
 #-----------------------------------------------------------------------------
 # Private API
