@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2020, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) 2012 - 2021, Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -14,6 +14,10 @@ import pytest ; pytest
 # Imports
 #-----------------------------------------------------------------------------
 
+# Standard library imports
+import sys
+from subprocess import run
+
 # External imports
 from tornado.ioloop import IOLoop
 
@@ -34,11 +38,15 @@ class FakeSess:
 # General API
 #-----------------------------------------------------------------------------
 
+@pytest.mark.skipif(sys.platform != "win32" or sys.version_info < (3, 8), reason="event loop test only for win, py>=3.8")
+def test_windows_event_loop_fixup():
+    proc = run([sys.executable, "-c", "import asyncio, sys; import bokeh.client.connection; sys.exit(int(isinstance(asyncio.get_event_loop_policy(), asyncio.WindowsProactorEventLoopPolicy)))"'']) # noqa
+    assert proc.returncode == 0, "bokeh.client did not fixup windows event loop"
+
 #-----------------------------------------------------------------------------
 # Dev API
 #-----------------------------------------------------------------------------
 
-
 class Test_ClientConnection:
     def test_creation(self) -> None:
         c = bcc.ClientConnection("session", "wsurl")
